@@ -104,6 +104,7 @@ define!({
         Function(Function),
         Bin(BinValue),
         Delimiter(Delimiter),
+        Urange(Urange),
         Tokens(Tokens),
         Url(Url),
     }
@@ -232,6 +233,11 @@ define!({
         Function(Function),
     }
 
+    pub struct Urange {
+        pub span: Span,
+        pub value: JsWord,
+    }
+
     pub struct SelectorList {
         pub span: Span,
         pub children: Vec<ComplexSelector>,
